/// <reference path="GestureSupportElement.js" />

import { EventEmitter, Renderer, ElementRef, OnInit } from "@angular/core";
import { Vector, Bounds } from "divkit.jsbundle.drawing";
import { MisclickEventArgs } from "./MisclickEventArgs";
import { GesturingEventArgs } from "./GesturingEventArgs";
import { TapEventArgs } from "./TapEventArgs";
import { MoveEventArgs } from "./MoveEventArgs";
import { GestureHistory } from "./GestureHistory";

export declare class GestureSupportElement implements OnInit {
    public OnMisclick: EventEmitter<MisclickEventArgs>;
    public OnInitialize: EventEmitter<GestureSupportElement>;
    public OnDrawing: EventEmitter<GesturingEventArgs>;
    public OnDrawingCompleted: EventEmitter<GesturingEventArgs>;
    public OnTap: EventEmitter<TapEventArgs>;
    public OnMove: EventEmitter<MoveEventArgs>;
    public OnMoveEnd: EventEmitter<any>;
    public GestureDisabled: boolean;
    public ClearOnLeave: boolean;
    public AutoTidy: boolean;
    public TidyThreshold: number;
    public SlopeThreshold: number;
    public PreventDefault: boolean;
    public MouseButtons: number[];
    public FullBounds: boolean;
    public FullHistory: boolean;
    public UpdateBoundsOnMove: boolean;
    public DetectMisclick: boolean;
    public IsDraggableElement: boolean;
    private __container: any;
    private __drawing: boolean;
    private __focusIn: boolean;
    private __history: GestureHistory[];
    private __bounds: Bounds;
    private __current: Vector;
    private __begin: Vector;
    private __parentOffset: Vector;
    private __tapCount: number;
    private __tapTime: number;
    private __tapTimeout: NodeJS.Timer;
    private __tapDelay: number;
    public Drawing();
    public History();
    public Bounds();
    constructor(el: ElementRef, renderer: Renderer);
    private IsCorrectButton(...args: any[]);
    onMouseDown(...args:any[]);
    onMouseUp();
    onMouseMove(...args:any[]);
    onMouseLeave();
    onMouseEnter();
    onTouchStart(...args:any[]);
    onTouchMove(...args:any[]);
    onTouchEnd();
    onTouchCancel();
    private TapEndHandler();
    private CheckTapCount();
    private Initialize(...args:any[])
    private MoveTo(x: number, y: number)
    private SetLocation(point:Vector);
    private GetBounds();
    private GesturingEventHandler(complete: boolean);
    private CheckForTidy();
    public Tidy();
    public ngOnInit();

}

export declare class GestureSupportModule { }



